smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame

# ``smartcard`.`wx`.`SimpleSCardAppFrame`.`SimpleSCardAppFrame``

class documentation

`class SimpleSCardAppFrame(wx.Frame):`

View In Hierarchy

The main frame of the simple smartcard application.

Method | `__init__` | Constructor. Creates the frame with two panels:
Method | `OnCloseFrame` | Called when frame is closed, i.e. on wx.EVT_CLOSE
Method | `OnExit` | Called when frame application exits.
Method | `OnReaderComboBox` | Called when the user activates a reader in the toolbar combo box.
Instance Variable | `apdutracerpanel` | Undocumented
Instance Variable | `toolbar` | Undocumented
Instance Variable | `treeuserpanel` | Undocumented

def __init__(self, appname, apppanelclass, appstyle, appicon, pos=(-1, -1), size=(-1, -1)):

Constructor. Creates the frame with two panels:

- the left-hand panel is holding the smartcard and/or reader tree
- the right-hand panel is holding the application dialog

Parameters
appname | name of the application
apppanelclass | the class of the panel to instantiate in the `SimpleSCardAppFrame`
appstyle | a combination of the following styles (bitwise or |) TR_SMARTCARD: display a smartcard tree panel TR_READER: display a reader tree panel TB_SMARTCARD: display a smartcard toolbar TB_SMARTCARD: display a reader toolbar PANEL_APDUTRACER: display an APDU tracer panel default is TR_DEFAULT = TR_SMARTCARD
appicon | Undocumented
pos | the application position as a (x,y) tupple; default is (-1,-1)
size | the application window size as a (x,y) tuple; default is (-1,-1)

def OnCloseFrame(self, evt):

Called when frame is closed, i.e. on wx.EVT_CLOSE

def OnExit(self, evt):

Called when frame application exits.

def OnReaderComboBox(self, event):

Called when the user activates a reader in the toolbar combo box.

apdutracerpanel =

Undocumented

toolbar =

Undocumented

treeuserpanel =

Undocumented